/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.social.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import java.io.Serializable;
import java.util.Date;

/**
 * 自动化日志
 *
 * @author hgw
 * @date 2024-08-30 10:27:16
 */
@Data
public class TSocialSoldierLogExportVo extends RowIndex implements Serializable {

	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("主键")
	@Schema(description = "主键")
	private String id;

	@ExcelAttribute(name = "员工姓名", maxLength = 20)
	@Schema(description = "员工姓名")
	@ExcelProperty("员工姓名")
	private String empName;

	@ExcelAttribute(name = "身份证号", isNotEmpty = true, errorInfo = "身份证号 不能为空", maxLength = 20)
	@Schema(description = "身份证号")
	@ExcelProperty("身份证号")
	private String empIdcard;

	@ExcelAttribute(name = "日期", isDate = true, dateFormat = "yyyy-MM-dd HH:mm")
	@Schema(description = "日期")
	@ExcelProperty("日期")
	private Date createTime;

	@ExcelAttribute(name = "派单项", maxLength = 2)
	@Length(max = 2, message = "派单项：社保;医保不能超过2个字符")
	@ExcelProperty("派单项：社保;医保")
	@Schema(description = "派单项：社保;医保")
	private String dispatchItem;

	@ExcelAttribute(name = "社保户", maxLength = 50)
	@Length(max = 2, message = "社保户不能超过50个字符")
	@ExcelProperty("社保户")
	@Schema(description = "社保户")
	private String socialHuName;

	@ExcelAttribute(name = "类型", maxLength = 2)
	@Length(max = 2, message = "类型：提交；审核不能超过2个字符")
	@ExcelProperty("类型：提交；审核")
	@Schema(description = "类型：提交；审核")
	private String type;

	@Length(max = 50, message = "结果 不能超过50 个字符")
	@ExcelAttribute(name = "结果", maxLength = 50)
	@Schema(description = "结果")
	@ExcelProperty("结果")
	private String remark;

}
